@@ -45,9 +45,13 @@ namespace Breeze
         const int height = decoration->buttonHeight();
         setGeometry(QRect(0, 0, height, height));
 
-        // connect hover state changed
+        // connections
+        connect(decoration->client().data(), SIGNAL(iconChanged(QIcon)), this, SLOT(update()));
+        connect(decoration->settings().data(), &KDecoration2::DecorationSettings::reconfigured, this, &Button::reconfigure);
         connect( this, &KDecoration2::DecorationButton::hoveredChanged, this, &Button::updateAnimationState );
 
+        reconfigure();
+
     }
 
     //__________________________________________________________________
@@ -436,6 +440,16 @@ namespace Breeze
 
     }
 
+    //________________________________________________________________
+    void Button::reconfigure()
+    {
+
+        // animation
+        auto d = qobject_cast<Decoration*>(decoration());
+        if( d )  m_animation->setDuration( d->internalSettings()->animationsDuration() );
+
+    }
+
     //__________________________________________________________________
     void Button::updateAnimationState( bool hovered )
     {
