@@ -72,7 +72,7 @@ namespace Breeze
         , m_colorSettings()
         , m_animation( new QPropertyAnimation( this ) )
     {
-        // g_sDecoCount++;
+        g_sDecoCount++;
     }
 
     //________________________________________________________________
@@ -210,8 +210,14 @@ namespace Breeze
     {
         if( m_internalSettings->animationsEnabled() )
         {
+
             m_animation->setDirection( client().data()->isActive() ? QPropertyAnimation::Forward : QPropertyAnimation::Backward );
             if( m_animation->state() != QPropertyAnimation::Running ) m_animation->start();
+
+        } else {
+
+            update();
+
         }
     }
 
@@ -613,7 +619,7 @@ namespace Breeze
         // assign to shadow
         decorationShadow->setShadow(image);
 
-        // g_sShadow = decorationShadow;
+        g_sShadow = decorationShadow;
         setShadow(decorationShadow);
     }
 
